#!/usr/bin/python
# -*- coding: UTF-8 -*-
import os, string, sys, re
from urllib import unquote

trunk_re = re.compile(r'^(?:URL|Depot).*/(?P<project>[^/]+)/(trunk|wiki)/?(.*)$', re.MULTILINE) 
branch_re = \
  re.compile(r'^(?:URL|Depot).*/([^/]+)/(branches|releases|tags)/[^/]+/?(.*)$',
             re.MULTILINE) 

def get_info(path, use_svk):
  if use_svk:
    info = os.popen("svk info \"" + path + "\"").read()
  else:
    info = os.popen("svn info \"" + path + "\"").read()

  for r in [trunk_re, branch_re]:
    m = r.search(info)
    if m:
      break
  
  if not m:
    raise "Error trying to obtain path from: svn info %s" % path

  project = m.group(1)
  type = m.group(2)
  repo_path = m.group(3)

  return [project, unquote(repo_path)]

if len(sys.argv) < 2:
    statpath = "."
else:
    for x in sys.argv[1:]:
        os.stat(x)
    statpath = string.join(sys.argv[1:])

# fetch the list of modified data items.
if not os.path.exists('.svn'):
    raise "%s doesn't appear to be an SVN working copy" % statpath
    # possibly an svk working copy... let's check
    p = os.popen("svk st -q " + statpath)
    is_svk = True
else:
    p = os.popen("svn st -q " + statpath)
    is_svk = False
filelist = p.read()
p.close()

# Create a list of filenames/statuses
filelist = filelist.rstrip().split('\n')
modified_list = []

# strip any trailing white space from the entries
for i in xrange(len(filelist)):
  status = filelist[i][0:2]
  if is_svk:
    filename = filelist[i][4:].rstrip()
  else:  
    filename = filelist[i][7:].rstrip()

  # strip off the ./
  if filename[0:2] == './': filename = filename[2:]

  if status.strip():
    modified_list.append([status, filename.strip()])

filelist = modified_list

no_modifiers = re.compile(r"^(subversion|svn|svn-\d+\.\d+\.\d+)$")

print "\n"

for file in filelist:
  [project, file[1]] = get_info(file[1], is_svk)
    
  if no_modifiers.match(project):
    status = ''
    spacing = ''
  else:
    status = " [" + file[0].replace(' ', '.') + "]"
    spacing = ' '
  print spacing + "* " + file[1] + status;
  print "\n"

